@@ -1,8 +1,6 @@
-# -*- coding: utf-8 -*-
-
 import re
-from typing import Iterator, Tuple, Sequence, Set
 import tokenize
+from typing import Iterator, Sequence, Set, Tuple
 
 import pkg_resources
 
@@ -13,6 +11,8 @@ pkg_name = 'flake8-broken-line'
 pkg_version: str = pkg_resources.get_distribution(pkg_name).version
 
 _INVALID_LINE_BREAK = re.compile(r'(?<!\\)\\$', re.M)
+_INVALID_MULTILINE_BACKSLASH = re.compile(r'(?<![\']{3}|[\"]{3})\\$', re.M)
+CONDITIONS = [_INVALID_LINE_BREAK, _INVALID_MULTILINE_BACKSLASH]
 _IGNORED_TOKENS = frozenset((
     tokenize.STRING,
     tokenize.COMMENT,
@@ -38,7 +38,7 @@ def check_line_breaks(
         if line_token.start[0] in reported:
             continue  # There might be several tokens on a same line.
 
-        if _INVALID_LINE_BREAK.search(line_token.line):
+        if all(condition.search(line_token.line) for condition in CONDITIONS):
             yield (*line_token.start, _N400, 'check_line_breaks')
             reported.add(line_token.start[0])
 
